==> kdecoration-5.12.5-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDecoration2/KDecoration2Targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDecoration2::KDecoration2Private" for configuration ""
set_property(TARGET KDecoration2::KDecoration2Private APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDecoration2::KDecoration2Private PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.5.12.5"
  IMPORTED_SONAME_NOCONFIG "libkdecorations2private.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDecoration2::KDecoration2Private )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDecoration2::KDecoration2Private "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.5.12.5" )

# Import target "KDecoration2::KDecoration" for configuration ""
set_property(TARGET KDecoration2::KDecoration APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDecoration2::KDecoration PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDecoration2::KDecoration2Private"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdecorations2.so.5.12.5"
  IMPORTED_SONAME_NOCONFIG "libkdecorations2.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDecoration2::KDecoration )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDecoration2::KDecoration "${_IMPORT_PREFIX}/lib/libkdecorations2.so.5.12.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdecoration-5.12.90-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDecoration2/KDecoration2Targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDecoration2::KDecoration2Private" for configuration ""
set_property(TARGET KDecoration2::KDecoration2Private APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDecoration2::KDecoration2Private PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.5.12.90"
  IMPORTED_SONAME_NOCONFIG "libkdecorations2private.so.6"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDecoration2::KDecoration2Private )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDecoration2::KDecoration2Private "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.5.12.90" )

# Import target "KDecoration2::KDecoration" for configuration ""
set_property(TARGET KDecoration2::KDecoration APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDecoration2::KDecoration PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDecoration2::KDecoration2Private;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdecorations2.so.5.12.90"
  IMPORTED_SONAME_NOCONFIG "libkdecorations2.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDecoration2::KDecoration )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDecoration2::KDecoration "${_IMPORT_PREFIX}/lib/libkdecorations2.so.5.12.90" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
